# Snowman

<p align="center">
    <img alt="logo" src="https://raw.githubusercontent.com/ya7010/snowman-py/main/docs/images/logo.svg" width="300" />
</p>

<!-- --8<-- [start:badges] -->
<p align="center">
    <a href="https://ya7010.github.io/snowman-py/"><img alt="docs" src="https://github.com/ya7010/snowman-py/actions/workflows/docs.yml/badge.svg"></a>
    <a href="https://pypi.org/project/snowman-py"><img alt="pypi package" src="https://badge.fury.io/py/snowman-py.svg"></a>
    <a href="https://github.com/ya7010/snowman-py/actions"><img alt="python-test" src="https://github.com/ya7010/snowman-py/actions/workflows/ci_python.yml/badge.svg"></a>
    <a href="https://github.com/ya7010/snowman-py/actions"><img alt="rust-test" src="https://github.com/ya7010/snowman-py/actions/workflows/ci_rust.yml/badge.svg"></a>
</p>
<!-- --8<-- [end:badges] -->

**Snowman**: Pydantic Model Generator and Query Builder for [Snowflake](https://www.snowflake.com/).

---

**Documentation**: <a href="https://ya7010.github.io/snowman-py/" target="_blank">https://ya7010.github.io/snowman-py/</a>

**Source Code**: <a href="https://github.com/ya7010/snowman-py" target="_blank">https://github.com/ya7010/snowman-py</a>

---

## Install

```sh
pip install snowman-py
```
